diff mbox

various typo fix patches

Message ID alpine.DEB.2.00.1307050121300.8850@citymarket.hu
State New
Headers show

Commit Message

Veres Lajos July 4, 2013, 11:31 p.m. UTC
Hello,

Referencing to topic:
http://gcc.gnu.org/ml/gcc/2013-07/msg00017.html
Patches containing "-cl" are touching only changelogs.
The attached files contain the patches generated by
https://github.com/vlajos/misspell_fixer
to files/dirs from c to gcc in the
svn://gcc.gnu.org/svn/gcc/trunk
repository. (Mostly separated by gcc/* subdirectories.)
Manually revised one time and reverted some false corrections.
Though only touches living code a few times, a review by a more competent
(than me) developer is desirable.

Comments

Arnaud Charlet July 5, 2013, 6:14 a.m. UTC | #1
The Ada changes are OK.

Arno

On 5 juil. 2013, at 01:31, Veres Lajos <vlajos@gmail.com> wrote:

> Hello,
> 
> Referencing to topic:
> http://gcc.gnu.org/ml/gcc/2013-07/msg00017.html
> Patches containing "-cl" are touching only changelogs.
> The attached files contain the patches generated by
> https://github.com/vlajos/misspell_fixer
> to files/dirs from c to gcc in the
> svn://gcc.gnu.org/svn/gcc/trunk
> repository. (Mostly separated by gcc/* subdirectories.)
> Manually revised one time and reverted some false corrections.
> Though only touches living code a few times, a review by a more competent
> (than me) developer is desirable.
> 
> -- 
> Veres Lajos
> vlajos@gmail.com
> +36 20 438 5909
> <gcc.misspell-fixer.vlajos.20130705.gcc.g...s.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.fortran-cl.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.cp-cl.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc-cl.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.a...d.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.ada.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.ada-cl.patch>
> <gcc.misspell-fixer.vlajos.20130705.contrib.patch>
> <gcc.misspell-fixer.vlajos.20130705.boehm-gc.patch>
> <gcc.misspell-fixer.vlajos.20130705.main-cl.patch>
> <gcc.misspell-fixer.vlajos.20130705.gcc.t.patch>
diff mbox

Patch

Index: gcc/testsuite/ChangeLog
===================================================================
--- gcc/testsuite/ChangeLog	(revision 200682)
+++ gcc/testsuite/ChangeLog	(working copy)
@@ -5093,7 +5093,7 @@ 
 2013-01-08  Tejas Belagod  <tejas.belagod@arm.com>
 
 	* gcc.target/aarch64/vect-mull-compile.c: Explicitly scan for
-	instructions generated instead of number of occurances.
+	instructions generated instead of number of occurrences.
 
 2013-01-08  James Greenhalgh  <james.greenhalgh@arm.com>
 
Index: gcc/testsuite/ChangeLog-1993-2007
===================================================================
--- gcc/testsuite/ChangeLog-1993-2007	(revision 200682)
+++ gcc/testsuite/ChangeLog-1993-2007	(working copy)
@@ -7641,7 +7641,7 @@ 
 
 2007-06-28  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
 
-	* gfortran.dg/open_errors.f90: Check for existance of temptestfile.
+	* gfortran.dg/open_errors.f90: Check for existence of temptestfile.
 	If it exists, don't try to create it.
 
 2007-06-28  Geoffrey Keating  <geoffk@apple.com>
@@ -33330,7 +33330,7 @@ 
 
 2004-11-16  Nick Clifton  <nickc@redhat.com>
 
-	Revert patches accidentally commited during checkin of fixes for
+	Revert patches accidentally committed during checkin of fixes for
 	xstormy16 tests:
 	gcc.c-torture/execute/simd-4.c: Revert
 	gcc.dg/20040910-1.c: Revert.
@@ -43519,7 +43519,7 @@ 
 2003-07-09  John David Anglin  <dave.anglin@nrc-cnrc.gc.ca>
 
 	* gcc.dg/const-elim-1.c (dg-final): Change regexp to match labels
-	with zero or one occurence of `$' after the initial `L'.
+	with zero or one occurrence of `$' after the initial `L'.
 
 2003-07-08  Kazu Hirata  <kazu@cs.umass.edu>
 
@@ -45922,7 +45922,7 @@ 
 2003-02-26  Zdenek Dvorak  <rakdver@atrey.karlin.mff.cuni.cz>
 
 	* lib/scanasm.exp: Add support for counting numbers of
-	occurences.
+	occurrences.
 	* gcc.dg/unswitch-1.c, gcc.dg/peel-1.c, gcc.dg/unroll-1.c,
 	gcc.dg/unroll-2.c, gcc.dg/unroll-3.c: New tests.
 
@@ -57651,7 +57651,7 @@ 
 1999-04-17  Richard Henderson  <rth@cygnus.com>
 
 	* gcc.dg/uninit-9.c (func): Use __builtin_alloca instead of alloca
-	to avoid the need for a prototype to supress a warning.
+	to avoid the need for a prototype to suppress a warning.
 
 1999-04-07  Jim Wilson  <wilson@cygnus.com>
 
@@ -60785,7 +60785,7 @@ 
 	  keyword in keyphrase embeded in testcase source code. The
 	  XFAIL keyword must be at the end of the keyphrase line. It
 	  may optionally be followed by one or more target triplets.
-	  It has just occured that the handling of wildcards in the
+	  It has just occurred that the handling of wildcards in the
 	  target triplet may not be correct.
 
 1993-04-23  Mike Werner  (mtw@deneb.cygnus.com)
Index: gcc/testsuite/ChangeLog-2011
===================================================================
--- gcc/testsuite/ChangeLog-2011	(revision 200682)
+++ gcc/testsuite/ChangeLog-2011	(working copy)
@@ -637,8 +637,8 @@ 
 	* gfortran.dg/class_to_type_1.f03: New.
 	* gfortran.dg/type_to_class_1.f03: New.
 	* gfortran.dg/typebound_assignment_3.f03: Remove the error.
-	* gfortran.dg/auto_dealloc_2.f90: Occurences of __builtin_free now 2.
-	* gfortran.dg/class_19.f03: Occurences of __builtin_free now 8.
+	* gfortran.dg/auto_dealloc_2.f90: Occurrences of __builtin_free now 2.
+	* gfortran.dg/class_19.f03: Occurrences of __builtin_free now 8.
 
 2011-12-11  Thomas Koenig  <tkoenig@gcc.gnu.org>
 
Index: gcc/testsuite/ada/acats/tests/c3/c34008a.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/c3/c34008a.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/c3/c34008a.ada	(working copy)
@@ -30,7 +30,7 @@ 
 --     JRK 08/27/87  CREATED ORIGINAL TEST.
 --     PWN 11/30/94  REMOVED 'BASE USE ILLEGAL IN ADA 9X.
 --     PWN 01/31/95  REMOVED INCONSISTENCIES WITH ADA 9X.
---     DTN 11/30/95  REMOVED ATTIBUTES OF NON-OBJECTS.
+--     DTN 11/30/95  REMOVED ATTRIBUTES OF NON-OBJECTS.
 
 WITH SYSTEM; USE SYSTEM;
 WITH REPORT; USE REPORT;
Index: gcc/testsuite/ada/acats/tests/c3/c35503c.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/c3/c35503c.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/c3/c35503c.ada	(working copy)
@@ -50,7 +50,7 @@ 
      END IDENT;
 
 BEGIN
-     TEST ("C35503C", "THE ATTIBUTES 'IMAGE' AND 'VALUE' YIELD THE " &
+     TEST ("C35503C", "THE ATTRIBUTES 'IMAGE' AND 'VALUE' YIELD THE " &
                       "CORRECT RESULTS WHEN THE PREFIX IS AN " &
                       "INTEGER TYPE" );
 -- PART (A).
Index: gcc/testsuite/ada/acats/tests/c3/c35703a.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/c3/c35703a.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/c3/c35703a.ada	(working copy)
@@ -133,7 +133,7 @@ 
           USE BPKG;
      BEGIN
           IF A > B THEN
-               FAILED ( "REAL2'FIRST IS GREATER THEN REAL2'LAST" );
+               FAILED ( "REAL2'FIRST IS GREATER THAN REAL2'LAST" );
           END IF;
      END;
 
Index: gcc/testsuite/ada/acats/tests/c7/c74211a.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/c7/c74211a.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/c7/c74211a.ada	(working copy)
@@ -25,10 +25,10 @@ 
 -- CHECK THAT WITHIN THE PACKAGE SPECIFICATION AND BODY, ANY EXPLICIT
 -- DECLARATIONS OF OPERATORS AND SUBPROGRAMS HIDE ANY OPERATIONS WHICH
 -- ARE IMPLICITLY DECLARED AT THE POINT OF THE FULL DECLARATION,
--- REGARDLESS OF THE ORDER OF OCCURENCE OF THE DECLARATIONS.
+-- REGARDLESS OF THE ORDER OF OCCURRENCE OF THE DECLARATIONS.
 
 -- CHECK THAT IMPLICITLY DECLARED DERIVED SUBPROGRAMS HIDE IMPLICITLY
--- DECLARED PREDEFINED OPERATORS, REGARDLESS OF THE ORDER OF OCCURENCE
+-- DECLARED PREDEFINED OPERATORS, REGARDLESS OF THE ORDER OF OCCURRENCE
 -- OF THE DECLARATIONS.
 
 -- DSJ 4/28/83
Index: gcc/testsuite/ada/acats/tests/c9/c91007a.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/c9/c91007a.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/c9/c91007a.ada	(working copy)
@@ -28,7 +28,7 @@ 
 --     "TASKING_ERROR" IS NOT RAISED.
 
 -- HISTORY:
---     LDC 06/17/88  CREATED ORGINAL TEST
+--     LDC 06/17/88  CREATED ORIGINAL TEST
 
 WITH REPORT;
 USE REPORT;
Index: gcc/testsuite/ada/acats/tests/ca/ca140280.a
===================================================================
--- gcc/testsuite/ada/acats/tests/ca/ca140280.a	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/ca/ca140280.a	(working copy)
@@ -36,7 +36,7 @@ 
 --         CA140283.AM
 --
 -- CHANGE HISTORY:
---     JBG 05/28/85  CREATED ORGINAL TEST.
+--     JBG 05/28/85  CREATED ORIGINAL TEST.
 --     RDH 04/18/90  ADDED CASES WHERE SUBPROGRAM PARAMETER TYPES ARE
 --                   NOT THE SAME.
 --     RLB 07/08/99  Reinstated withdrawn test; revised to Ada 95 format.
Index: gcc/testsuite/ada/acats/tests/ca/ca140281.a
===================================================================
--- gcc/testsuite/ada/acats/tests/ca/ca140281.a	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/ca/ca140281.a	(working copy)
@@ -36,7 +36,7 @@ 
 --         CA140283.AM
 --
 -- CHANGE HISTORY:
---     JBG 05/28/85  CREATED ORGINAL TEST.
+--     JBG 05/28/85  CREATED ORIGINAL TEST.
 --     RDH 04/18/90  ADDED CASES WHERE SUBPROGRAM PARAMETER TYPES ARE
 --                   NOT THE SAME.
 --     RLB 07/08/99  Reinstated withdrawn test; revised to Ada 95 format.
Index: gcc/testsuite/ada/acats/tests/ce/ce2103c.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/ce/ce2103c.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/ce/ce2103c.ada	(working copy)
@@ -93,7 +93,7 @@ 
           WHEN USE_ERROR =>
                IF IS_OPEN (TEST_FILE_ONE) /= FALSE THEN
                     FAILED ("IS_OPEN GIVES TRUE ON " &
-                            "UNSUCESSFUL OPEN");
+                            "UNSUCCESSFUL OPEN");
                END IF;
                RAISE INCOMPLETE;
      END;
Index: gcc/testsuite/ada/acats/tests/ce/ce3704e.ada
===================================================================
--- gcc/testsuite/ada/acats/tests/ce/ce3704e.ada	(revision 200682)
+++ gcc/testsuite/ada/acats/tests/ce/ce3704e.ada	(working copy)
@@ -37,7 +37,7 @@ 
 --     VKG 01/14/83
 --     RJW 11/04/86  REVISED TEST TO OUTPUT A NON_APPLICABLE
 --                   RESULT WHEN FILES ARE NOT SUPPORTED.
---     DWC 09/10/87  REMOVED UNNECCESSARY CODE, CORRECTED EXCEPTION
+--     DWC 09/10/87  REMOVED UNNECESSARY CODE, CORRECTED EXCEPTION
 --                   HANDLING, AND CHECKED FOR USE_ERROR ON DELETE.
 
 WITH REPORT; USE REPORT;
Index: gcc/testsuite/g++.dg/cpp0x/constexpr-ex1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/constexpr-ex1.C	(revision 200682)
+++ gcc/testsuite/g++.dg/cpp0x/constexpr-ex1.C	(working copy)
@@ -36,7 +36,7 @@ 
 // 4.2 const-expression data
 
 // 2
-// storage  not allocated untill address taken
+// storage  not allocated until address taken
 constexpr double x = 9484.748;
 const double* p = &x;          // the &x forces x into memory
 
Index: gcc/testsuite/g++.dg/ipa/devirt-3.C
===================================================================
--- gcc/testsuite/g++.dg/ipa/devirt-3.C	(revision 200682)
+++ gcc/testsuite/g++.dg/ipa/devirt-3.C	(working copy)
@@ -1,4 +1,4 @@ 
-/* Verify that simple virtual calls on an object refrence are
+/* Verify that simple virtual calls on an object reference are
    converted to simple calls by ipa-cp.  */
 /* { dg-do run } */
 /* { dg-options "-O3 -fno-early-inlining -fno-inline -fdump-ipa-cp -fdump-tree-optimized"  } */
Index: gcc/testsuite/g++.dg/ipa/ivinline-3.C
===================================================================
--- gcc/testsuite/g++.dg/ipa/ivinline-3.C	(revision 200682)
+++ gcc/testsuite/g++.dg/ipa/ivinline-3.C	(working copy)
@@ -1,4 +1,4 @@ 
-/* Verify that simple virtual calls on an object refrence are inlined
+/* Verify that simple virtual calls on an object reference are inlined
    even without early inlining.  */
 /* { dg-do run { target nonpic } } */
 /* { dg-options "-O3 -fdump-ipa-inline -fno-early-inlining -fno-ipa-cp"  } */
Index: gcc/testsuite/g++.dg/lookup/scoped5.C
===================================================================
--- gcc/testsuite/g++.dg/lookup/scoped5.C	(revision 200682)
+++ gcc/testsuite/g++.dg/lookup/scoped5.C	(working copy)
@@ -2,7 +2,7 @@ 
 
 // Origin: pepeaty@yahoo.com
 
-// PR c++/10230: ICE while determining if refered non-static member
+// PR c++/10230: ICE while determining if referred non-static member
 // is from a base type of the current class.
 
 class A {
Index: gcc/testsuite/g++.dg/opt/inline3.C
===================================================================
--- gcc/testsuite/g++.dg/opt/inline3.C	(revision 200682)
+++ gcc/testsuite/g++.dg/opt/inline3.C	(working copy)
@@ -1,5 +1,5 @@ 
 // PR opt/6793
-// We failed to supress inlining of a varargs function when it's a template.
+// We failed to suppress inlining of a varargs function when it's a template.
 // { dg-do compile }
 // { dg-options "-O3" }
 
Index: gcc/testsuite/g++.dg/other/vararg-1.C
===================================================================
--- gcc/testsuite/g++.dg/other/vararg-1.C	(revision 200682)
+++ gcc/testsuite/g++.dg/other/vararg-1.C	(working copy)
@@ -1,7 +1,7 @@ 
 // C++/15119
 //  This ICEd in substitute_placeholder_in_expr because it did not
 //  implement the 4 element trees.
-//  Orginal test by: <wanderer@rsu.ru>
+//  Original test by: <wanderer@rsu.ru>
 //  Reduced by: <bangerth@dealii.org>
 /* { dg-do compile } */
 
Index: gcc/testsuite/g++.old-deja/g++.benjamin/tem05.C
===================================================================
--- gcc/testsuite/g++.old-deja/g++.benjamin/tem05.C	(revision 200682)
+++ gcc/testsuite/g++.old-deja/g++.benjamin/tem05.C	(working copy)
@@ -9,7 +9,7 @@ 
 // A namespace-scope declaration or definintion of a non-line function
 // template, a non-inline member function template, a non-inline
 // member function of a class template or a static data member of a
-// class template may be preceeded by the export keyword. If such a
+// class template may be preceded by the export keyword. If such a
 // template is defined in the same translation unit in which it is
 // declared as exported, the definition is considered to be
 // exported. The first declaration of the template containing the
Index: gcc/testsuite/g++.old-deja/g++.brendan/crash29.C
===================================================================
--- gcc/testsuite/g++.old-deja/g++.brendan/crash29.C	(revision 200682)
+++ gcc/testsuite/g++.old-deja/g++.brendan/crash29.C	(working copy)
@@ -14,7 +14,7 @@ 
 int
 main()
 {
-	new GlobalAddress(Value());		// internal error occured here// { dg-error "no matching" }
+	new GlobalAddress(Value());		// internal error occurred here// { dg-error "no matching" }
 	// { dg-message "candidate" "candidate note" { target *-*-* } 17 }
 	//new GlobalAddress(new Value());	// This line is correct code
 }
Index: gcc/testsuite/g++.old-deja/g++.bugs/900215_02.C
===================================================================
--- gcc/testsuite/g++.old-deja/g++.bugs/900215_02.C	(revision 200682)
+++ gcc/testsuite/g++.old-deja/g++.bugs/900215_02.C	(working copy)
@@ -6,7 +6,7 @@ 
 // member functions of class X.
 
 // In effect, g++ treats any dereference of a pointer-to-member which appears
-// within the context of a member function (and which is not preceeded by
+// within the context of a member function (and which is not preceded by
 // either ->* or .*) as if it had been implicitly prefixed with this->*.
 
 // The 2.0 Reference Manual only provides that such implicit prefixing
Index: gcc/testsuite/g++.old-deja/g++.mike/p784.C
===================================================================
--- gcc/testsuite/g++.old-deja/g++.mike/p784.C	(revision 200682)
+++ gcc/testsuite/g++.old-deja/g++.mike/p784.C	(working copy)
@@ -1101,7 +1101,7 @@ 
   int               matches(const char* t, int pos = 0) const;
   int               matches(const Regex&      r, int pos = 0) const;
 
-//  return number of occurences of target in String
+//  return number of occurrences of target in String
 
   int               freq(char        c) const;
   int               freq(const String&     y) const;
Index: gcc/testsuite/g++.old-deja/g++.pt/typedef1.C
===================================================================
--- gcc/testsuite/g++.old-deja/g++.pt/typedef1.C	(revision 200682)
+++ gcc/testsuite/g++.old-deja/g++.pt/typedef1.C	(working copy)
@@ -1,5 +1,5 @@ 
 // { dg-do assemble  }
-// Testcase for handling of typedef wierdness.
+// Testcase for handling of typedef weirdness.
 
 template <class T>
 struct A
Index: gcc/testsuite/gcc.dg/tree-ssa/loop-19.c
===================================================================
--- gcc/testsuite/gcc.dg/tree-ssa/loop-19.c	(revision 200682)
+++ gcc/testsuite/gcc.dg/tree-ssa/loop-19.c	(working copy)
@@ -20,7 +20,7 @@ 
 /* Check that the memory references are based on &a and &c, with appropriate
    offsets.  Ideally, we would want each of them to appear once in the output.
    However, due to a bug in jump threading, we end up peeling one iteration from
-   the loop, which creates an additional occurence.  */
+   the loop, which creates an additional occurrence.  */
 
 /* { dg-final { scan-tree-dump-times "MEM.(base: &|symbol: )a," 2 "optimized" } } */
 /* { dg-final { scan-tree-dump-times "MEM.(base: &|symbol: )c," 2 "optimized" } } */
Index: gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-2.c
===================================================================
--- gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-2.c	(revision 200682)
+++ gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-2.c	(working copy)
@@ -14,7 +14,7 @@ 
   /* else */
   return 0;
 
-  /* then - returing 1 causes phiopt to trigger */
+  /* then - returning 1 causes phiopt to trigger */
 doit:
   return 2;
 }
Index: gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-3.c
===================================================================
--- gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-3.c	(revision 200682)
+++ gcc/testsuite/gcc.dg/tree-ssa/ssa-ifcombine-3.c	(working copy)
@@ -14,7 +14,7 @@ 
   /* else */
   return 0;
 
-  /* then - returing 1 causes phiopt to trigger */
+  /* then - returning 1 causes phiopt to trigger */
 doit:
   return 2;
 }
Index: gcc/testsuite/gfortran.dg/func_derived_4.f90
===================================================================
--- gcc/testsuite/gfortran.dg/func_derived_4.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/func_derived_4.f90	(working copy)
@@ -1,6 +1,6 @@ 
 ! { dg-do run }
 ! PR fortran/30793
-! Check that pointer-returing functions
+! Check that pointer-returning functions
 ! work derived types.
 !
 ! Contributed by Salvatore Filippone.
Index: gcc/testsuite/gfortran.dg/inline_sum_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/inline_sum_2.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/inline_sum_2.f90	(working copy)
@@ -6,7 +6,7 @@ 
 
 ! We can't check for the absence of temporary arrays generated on the run-time
 ! testcase, as inlining is disabled at -Os, so it will fail in that case.
-! Thus, the test is splitted into two independant files, one checking for
+! Thus, the test is splitted into two independent files, one checking for
 ! the absence of temporaries, and one (this one) checking that the code
 ! generated remains valid at all optimization levels.
 include 'inline_sum_1.f90'
Index: gcc/testsuite/gfortran.dg/inquire_11.f90
===================================================================
--- gcc/testsuite/gfortran.dg/inquire_11.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/inquire_11.f90	(working copy)
@@ -1,5 +1,5 @@ 
 ! { dg-do compile }
-! PR 33055 Runtime error in INQUIRE unit existance with -fdefault-integer-8
+! PR 33055 Runtime error in INQUIRE unit existence with -fdefault-integer-8
 ! Test case from PR33217 prepared by Jerry DeLisle <jvdelisle@gcc.gnu.org>
 MODULE print_it
 CONTAINS
Index: gcc/testsuite/gfortran.dg/interface_23.f90
===================================================================
--- gcc/testsuite/gfortran.dg/interface_23.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/interface_23.f90	(working copy)
@@ -1,7 +1,7 @@ 
 ! { dg-do compile }
 !
 ! This tests the fix for PR36325, which corrected for the fact that a
-! specific or generic INTERFACE statement implies the EXTERNAL attibute.
+! specific or generic INTERFACE statement implies the EXTERNAL attribute.
 !
 ! Contributed by Janus Weil <janus@gcc.gnu.org>
 
Index: gcc/testsuite/gfortran.dg/interface_28.f90
===================================================================
--- gcc/testsuite/gfortran.dg/interface_28.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/interface_28.f90	(working copy)
@@ -20,11 +20,11 @@ 
 module sub
   contains
   subroutine subActual(x)
-    ! actual subroutine's argment is different in intent
+    ! actual subroutine's argument is different in intent
     integer, intent(inout),optional:: x
   end subroutine
   subroutine subActual2(x)
-    ! actual subroutine's argment is missing OPTIONAL
+    ! actual subroutine's argument is missing OPTIONAL
     integer, intent(in):: x
   end subroutine
 end module
Index: gcc/testsuite/gfortran.dg/namelist_23.f90
===================================================================
--- gcc/testsuite/gfortran.dg/namelist_23.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/namelist_23.f90	(working copy)
@@ -4,49 +4,49 @@ 
 ! Contributed by Jerry DeLisle  <jvdelisle@gcc.gnu.org>
 program read_logical
    implicit none
-   logical, dimension(4) :: truely
-   integer, dimension(4) :: truely_a_very_long_variable_name
-   namelist /mynml/ truely
-   namelist /mynml/ truely_a_very_long_variable_name
+   logical, dimension(4) :: truly
+   integer, dimension(4) :: truly_a_very_long_variable_name
+   namelist /mynml/ truly
+   namelist /mynml/ truly_a_very_long_variable_name
 
-   truely = .false.
-   truely_a_very_long_variable_name = 0
+   truly = .false.
+   truly_a_very_long_variable_name = 0
 
    open(10, status="scratch")
    write(10,*) "&mynml"
-   write(10,*) "truely       = trouble,    traffic .true"
-   write(10,*) "truely_a_very_long_variable_name  = 4,      4,      4"
+   write(10,*) "truly       = trouble,    traffic .true"
+   write(10,*) "truly_a_very_long_variable_name  = 4,      4,      4"
    write(10,*) "/"
    rewind(10)
    read (10, nml=mynml, err = 1000)
-   if (.not.all(truely(1:3))) call abort()
-   if (.not.all(truely_a_very_long_variable_name(1:3).eq.4)) call abort()
+   if (.not.all(truly(1:3))) call abort()
+   if (.not.all(truly_a_very_long_variable_name(1:3).eq.4)) call abort()
    
-   truely = .false.
-   truely_a_very_long_variable_name = 0
+   truly = .false.
+   truly_a_very_long_variable_name = 0
 
    rewind(10)
    write(10,*) "&mynml"
-   write(10,*) "truely       = .true., .true.,"
-   write(10,*) "truely_a_very_long_variable_name  = 4,      4,      4"
+   write(10,*) "truly       = .true., .true.,"
+   write(10,*) "truly_a_very_long_variable_name  = 4,      4,      4"
    write(10,*) "/"
    rewind(10)
    read (10, nml=mynml, err = 1000)
-   if (.not.all(truely(1:2))) call abort()
-   if (.not.all(truely_a_very_long_variable_name(1:3).eq.4)) call abort()
+   if (.not.all(truly(1:2))) call abort()
+   if (.not.all(truly_a_very_long_variable_name(1:3).eq.4)) call abort()
 
-   truely = .true.
-   truely_a_very_long_variable_name = 0
+   truly = .true.
+   truly_a_very_long_variable_name = 0
 
    rewind(10)
    write(10,*) "&mynml"
-   write(10,*) "truely       = .false., .false.,"
-   write(10,*) "truely_a_very_long_variable_name  = 4,      4,      4"
+   write(10,*) "truly       = .false., .false.,"
+   write(10,*) "truly_a_very_long_variable_name  = 4,      4,      4"
    write(10,*) "/"
    rewind(10)
    read (10, nml=mynml, err = 1000)
-   if (all(truely(1:2))) call abort()
-   if (.not.all(truely_a_very_long_variable_name(1:3).eq.4)) call abort()
+   if (all(truly(1:2))) call abort()
+   if (.not.all(truly_a_very_long_variable_name(1:3).eq.4)) call abort()
    close(10)
    stop
 1000 call abort()
Index: gcc/testsuite/gfortran.dg/negative_unit.f
===================================================================
--- gcc/testsuite/gfortran.dg/negative_unit.f	(revision 200682)
+++ gcc/testsuite/gfortran.dg/negative_unit.f	(working copy)
@@ -2,7 +2,7 @@ 
 !
 ! PR libfortran/20660 and other bugs (not filed in bugzilla) relating
 ! to negative units
-! PR 33055 Runtime error in INQUIRE unit existance with -fdefault-integer-8
+! PR 33055 Runtime error in INQUIRE unit existence with -fdefault-integer-8
 ! Test case update by Jerry DeLisle <jvdelisle@gcc.gnu.org>
 !
 ! Bugs submitted by Walt Brainerd
Index: gcc/testsuite/gfortran.dg/negative_unit_int8.f
===================================================================
--- gcc/testsuite/gfortran.dg/negative_unit_int8.f	(revision 200682)
+++ gcc/testsuite/gfortran.dg/negative_unit_int8.f	(working copy)
@@ -5,7 +5,7 @@ 
 !
 ! PR libfortran/20660 and other bugs (not filed in bugzilla) relating
 ! to negative units
-! PR 33055 Runtime error in INQUIRE unit existance with -fdefault-integer-8
+! PR 33055 Runtime error in INQUIRE unit existence with -fdefault-integer-8
 ! Test case update by Jerry DeLisle <jvdelisle@gcc.gnu.org>
 !
 ! Bugs submitted by Walt Brainerd
Index: gcc/testsuite/gfortran.dg/open_readonly_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/open_readonly_1.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/open_readonly_1.f90	(working copy)
@@ -1,7 +1,7 @@ 
 ! { dg-do run { target fd_truncate } }
 ! PR19451
 ! Writing to a non-empty readonly file caused a segfault.
-! We were still trying to write the EOR after an error ocurred
+! We were still trying to write the EOR after an error occurred
 program prog
   open (unit=10, file='PR19451.dat')
   write (10,*) "Hello World"
Index: gcc/testsuite/gfortran.dg/private_type_14.f90
===================================================================
--- gcc/testsuite/gfortran.dg/private_type_14.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/private_type_14.f90	(working copy)
@@ -2,7 +2,7 @@ 
 !
 ! PR fortran/51378
 !
-! Allow constructor to nonprivate parent compoents,
+! Allow constructor to nonprivate parent components,
 ! even if the extension specified PRIVATE for its own components
 !
 ! Contributed by Reinhold Bader
Index: gcc/testsuite/gfortran.dg/reassoc_5.f90
===================================================================
--- gcc/testsuite/gfortran.dg/reassoc_5.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/reassoc_5.f90	(working copy)
@@ -11,7 +11,7 @@ 
 end
 
 ! Test copied from reassoc_1.f90 which checked for -fprotect-parens (default),
-! and thus for the occurance of "5 - 5".
+! and thus for the occurrence of "5 - 5".
 !
 ! We need an explicit +5 and -5, and an intermediate ((bla)) expression
 ! (the reassoc barrier).  Make use of "." matching lineends.
Index: gcc/testsuite/gfortran.dg/result_in_spec_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/result_in_spec_2.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/result_in_spec_2.f90	(working copy)
@@ -1,5 +1,5 @@ 
 ! { dg-do run }
-! Tests the fix for PR32047, in which the null agument
+! Tests the fix for PR32047, in which the null argument
 ! function for the character length would cause an ICE.
 !
 ! Contributed by Tobias Burnus <burnus@gcc.gnu.org >
Index: gcc/testsuite/gfortran.dg/transfer_array_intrinsic_3.f90
===================================================================
--- gcc/testsuite/gfortran.dg/transfer_array_intrinsic_3.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/transfer_array_intrinsic_3.f90	(working copy)
@@ -6,12 +6,12 @@ 
 !
 ! Contributed by Brooks Moses <brooks@gcc.gnu.org>
 !
-function NumOccurances (string, chr, isel) result(n)

+function NumOccurrences (string, chr, isel) result(n)

   character(*),intent(in) :: string
   character(1),intent(in) :: chr
   integer :: isel
 !
-! return number of occurances of character in given string

+! return number of occurrences of character in given string

 !
     select case (isel)
       case (1)
@@ -28,9 +28,9 @@ 
   return
 end
 
-  if (NumOccurances("abacadae", "a", 1) .ne. 4) call abort ()

-  if (NumOccurances("abacadae", "a", 2) .ne. 4) call abort ()

-  if (NumOccurances("abacadae", "a", 3) .ne. 4) call abort ()

-  if (NumOccurances("abacadae", "a", 4) .ne. 4) call abort ()

-  if (NumOccurances("abacadae", "a", 5) .ne. 4) call abort ()

+  if (NumOccurrences("abacadae", "a", 1) .ne. 4) call abort ()

+  if (NumOccurrences("abacadae", "a", 2) .ne. 4) call abort ()

+  if (NumOccurrences("abacadae", "a", 3) .ne. 4) call abort ()

+  if (NumOccurrences("abacadae", "a", 4) .ne. 4) call abort ()

+  if (NumOccurrences("abacadae", "a", 5) .ne. 4) call abort ()

 end
Index: gcc/testsuite/gfortran.dg/whole_file_27.f90
===================================================================
--- gcc/testsuite/gfortran.dg/whole_file_27.f90	(revision 200682)
+++ gcc/testsuite/gfortran.dg/whole_file_27.f90	(working copy)
@@ -177,7 +177,7 @@ 
 ! !$    call a%set_triangle(.false.)
 ! !$    call a%set_unit(.false.)
 ! !$    call a%set_dupl(dupl_def_)
-    write(0,*) 'Allocated COO succesfully, should now set components'
+    write(0,*) 'Allocated COO successfully, should now set components'
   else 
     write(0,*) 'COO allocation failed somehow. Go figure'
   end if
Index: gcc/testsuite/gfortran.fortran-torture/execute/st_function.f90
===================================================================
--- gcc/testsuite/gfortran.fortran-torture/execute/st_function.f90	(revision 200682)
+++ gcc/testsuite/gfortran.fortran-torture/execute/st_function.f90	(working copy)
@@ -72,7 +72,7 @@ 
    end subroutine
 end
 
-! This functon returns the argument passed on the previous call.
+! This function returns the argument passed on the previous call.
 integer function fun2 (i)
   integer i
   integer, save :: val = 1
Index: gcc/testsuite/go.test/test/bench/shootout/meteor-contest.c
===================================================================
--- gcc/testsuite/go.test/test/bench/shootout/meteor-contest.c	(revision 200682)
+++ gcc/testsuite/go.test/test/bench/shootout/meteor-contest.c	(working copy)
@@ -186,7 +186,7 @@ 
    }
 }
 
-/* Returns wether the specified cell and direction will land outside
+/* Returns whether the specified cell and direction will land outside
  * of the board.  Used to determine if a piece is at a legal board
  * location or not.
  */
Index: gcc/testsuite/go.test/test/bench/shootout/meteor-contest.go
===================================================================
--- gcc/testsuite/go.test/test/bench/shootout/meteor-contest.go	(revision 200682)
+++ gcc/testsuite/go.test/test/bench/shootout/meteor-contest.go	(working copy)
@@ -203,7 +203,7 @@ 
 	return cell
 }
 
-/* Returns wether the specified cell and direction will land outside
+/* Returns whether the specified cell and direction will land outside
  * of the board.  Used to determine if a piece is at a legal board
  * location or not.
  */
Index: gcc/tree-eh.c
===================================================================
--- gcc/tree-eh.c	(revision 200682)
+++ gcc/tree-eh.c	(working copy)
@@ -851,10 +851,10 @@ 
 /* We want to transform
 	try { body; } catch { stuff; }
    to
-	normal_seqence:
+	normal_sequence:
 	  body;
 	  over:
-	eh_seqence:
+	eh_sequence:
 	  landing_pad:
 	  stuff;
 	  goto over;
@@ -4383,7 +4383,7 @@ 
     2) MUST_NOT_THROW regions that became dead because of 1) are optimized out
     3) Info about regions that are containing instructions, and regions
        reachable via local EH edges is collected
-    4) Eh tree is pruned for regions no longer neccesary.
+    4) Eh tree is pruned for regions no longer necessary.
 
    TODO: Push MUST_NOT_THROW regions to the root of the EH tree.
 	 Unify those that have the same failure decl and locus.
Index: gcc/tree-ssa-dce.c
===================================================================
--- gcc/tree-ssa-dce.c	(revision 200682)
+++ gcc/tree-ssa-dce.c	(working copy)
@@ -1110,7 +1110,7 @@ 
   e2 = redirect_edge_and_branch (e, post_dom_bb);
   cfg_altered = true;
 
-  /* If edge was already around, no updating is neccesary.  */
+  /* If edge was already around, no updating is necessary.  */
   if (e2 != e)
     return e2;
 
Index: gcc/tree-ssa-reassoc.c
===================================================================
--- gcc/tree-ssa-reassoc.c	(revision 200682)
+++ gcc/tree-ssa-reassoc.c	(working copy)
@@ -1386,7 +1386,7 @@ 
 	}
     }
 
-  /* Process the (operand, code) pairs in order of most occurence.  */
+  /* Process the (operand, code) pairs in order of most occurrence.  */
   candidates2 = sbitmap_alloc (length);
   while (!cvec.is_empty ())
     {
Index: gcc/testsuite/objc.dg/torture/forward-1.m
===================================================================
--- gcc/testsuite/objc.dg/torture/forward-1.m	(revision 200682)
+++ gcc/testsuite/objc.dg/torture/forward-1.m	(working copy)
@@ -38,7 +38,7 @@ 
 -display
 {
   printf ("Executing display\n");
     /* Check to see if we are really the reciever. */
     if (self != receiver)
         abort ();
     /* And the value of foo is set correctly. */
@@ -58,7 +58,7 @@ 
 }
 -(void *) forward: (SEL)theSel: (void *)theArgFrame
 {
   /* If we have a reciever try to perform on that object */
     if (receiver)
       {
 	/* Simple forward that works for methods with no
@@ -78,12 +78,12 @@ 
 @end
 int main()
 {
     /* Init the reciever. */
     receiver = [[Receiver alloc] initWithFoo: VALUETOUSE];
     /* Init the fowarder. */
     forwarder = [[Forwarder alloc] initWithReceiver: receiver];
     /* Call display on the forwarder which in turns calls display on
-       the reciever. */
+       the receiver. */
     [forwarder display];
     exit(0);
 }
@@ -38,7 +38,7 @@ 
 {
   printf ("Executing display\n");
-    /* Check to see if we are really the reciever. */
+    /* Check to see if we are really the receiver. */
     if (self != receiver)
         abort ();
@@ -58,7 +58,7 @@ 
 -(void *) forward: (SEL)theSel: (void *)theArgFrame
 {
-  /* If we have a reciever try to perform on that object */
+  /* If we have a receiver try to perform on that object */
     if (receiver)
       {
@@ -78,12 +78,12 @@ 
 int main()
 {
-    /* Init the reciever. */
+    /* Init the receiver. */
     receiver = [[Receiver alloc] initWithFoo: VALUETOUSE];
     /* Init the fowarder. */